---
test_data: TD_99_99_88_75
test_title: mutually exclusive arg vals from diff arg types
---

Case: two different `arg_type`-s where `data_envelope`-s prop values have mutually exclusive combinations.

# Example

Imagine 2 `ServicePropName`-s:
*   `geo_region`
*   `code_maturity`

Imagine 3 `data_envelope`-s:

```yaml
data_envelope_1:
    geo_region: apac
    code_maturity: qa
data_envelope_2:
    geo_region: emea
    code_maturity: dev
```
There are 4 combinations of args and 2 are not mutually exclusive combinations:
*   selects `data_envelope_1`: apac qa
*   selects `data_envelope_2`: emea dev
*   mutually exclusive combinations (selects no `data_envelope`): emea qa
*   mutually exclusive combinations (selects no `data_envelope`): apac dev

The behavior is governed by FS_44_36_84_88 consume args one by one.

Other related features:
*   FS_51_67_38_37 impossible arg combinations
*   FS_90_48_11_45 forced assignment from entire type value space
